import { Ref, onBeforeUnmount, onMounted, ref } from 'vue'
import { addResizeListener, removeResizeListener } from '../dom'
import { debounce } from 'lodash-es'

export default function useElTableColumnWidth(
  selector: string,
): [Ref<HTMLElement | null>, Ref<number>] {
  const tableWrapperRef = ref<HTMLDivElement | null>(null)
  const width = ref(0)

  let cleanupResizeEventListener: (() => void) | undefined
  let cleanupThResizeEventListener: (() => void) | undefined

  let currentTh: HTMLElement | null = null
  const onThResize = () => {
    if (currentTh) width.value = currentTh.offsetWidth
  }
  const watchThSizeChange = (th: HTMLElement) => {
    if (currentTh === th) return
    currentTh = th
    cleanupThResizeEventListener?.()
    addResizeListener(th, onThResize)
    cleanupThResizeEventListener = () => {
      removeResizeListener(th, onThResize)
      currentTh = null
    }
  }

  const onTableWrapperResize = debounce(() => {
    const el = tableWrapperRef.value
    if (!el) return
    const th = el.querySelector(selector) as HTMLElement | null
    if (th) {
      width.value = th.offsetWidth
      watchThSizeChange(th)
    }
  }, 50)

  onMounted(() => {
    const el = tableWrapperRef.value
    if (!el) return
    cleanupResizeEventListener = () => {
      removeResizeListener(el, onTableWrapperResize)
    }
    addResizeListener(el, onTableWrapperResize)
  })

  onBeforeUnmount(() => {
    cleanupResizeEventListener?.()
    cleanupThResizeEventListener?.()
  })

  return [tableWrapperRef, width]
}
