import { getQaOrderBySubOrderNumber, qaFinishedApi } from '@/api/order'
import { InspectionData, QaData, shopRemark } from '@/types/api/order'
import { useValue } from '@/utils/hooks/useValue'
import { showConfirm } from '@/utils/ui'
import { computed, ref } from 'vue'

export default function useQuarantine() {
  const [sourceData, resetOrderList] = useValue<QaData[]>([])
  const [currentRow, resetCurrentRow] = useValue<QaData>({})

  const quarantineVisible = ref(false)
  const qaCode = ref('')
  const qaInputRef = ref()
  const isLock = ref(false)
  const cloneRow = ref<QaData>({} as QaData)
  const activeTab = ref('all')
  const _sourceData = ref<QaData[]>([] as QaData[])
  const allTotal = ref(0)
  const dzjTotal = ref(0)
  const yzjTotal = ref(0)

  const confirmCheck = () => {
    quarantineVisible.value = true
    resetOrderList()
    resetCurrentRow()
    dzjTotal.value = 0
    yzjTotal.value = 0
    allTotal.value = 0
  }
  const isQaed = computed(() => {
    if (sourceData.value.length == 0) return false
    return sourceData.value.some((item) => item.isCheck)
  })
  const searchQaByOrderNumber = () => {
    const code = qaCode.value
    if (!code) {
      isLock.value = false
      playAudio('picking_warning')
      return ElMessage({
        message: '请录入质检单号',
        type: 'warning',
        offset: window.innerHeight / 2,
      })
    }
    if (isLock.value) {
      qaInputRef.value.focus()
      qaCode.value = ''
      return
    }
    isLock.value = true
    const code1 = code?.split('_')[0]
    // 如果扫单号没有包含当前的生产单号
    const isIncluned = sourceData.value.some(
      (item) =>
        item.factorySubOrderNumber == code1 || item.subOrderNumber == code1,
    )
    if (isQaed.value && !isIncluned) {
      saveQuarantine(() => {
        loadShipmentOrderByCode(code)
      })
    } else {
      // 如果质检未完成
      // 查找是否已经存在
      const row = sourceData.value.find(
        (item) =>
          item.factorySubOrderNumber == code1 || item.subOrderNumber == code1,
      )
      if (row) {
        // 质检数量不能大于发货数量
        const num = (row.passNum || 0) + (row.notPassNum || 0)
        if (num > (row.shipmentNum || 0)) {
          qaInputRef.value.focus()
          isLock.value = false
          qaCode.value = ''
          playAudio('picking_beyond')
          return ElMessage({
            message: '质检数量不能大于发货数量',
            type: 'warning',
            offset: window.innerHeight / 2,
          })
        }
        playAudio('picking_check_success')
        // row.passNum = row.shipmentNum
        qaInputRef.value.focus()
        currentRow.value = row
        cloneRow.value = JSON.parse(JSON.stringify(currentRow.value))
        isLock.value = false
        qaCode.value = ''
      } else {
        loadShipmentOrderByCode(code)
      }
    }
  }
  const loadShipmentOrderByCode = async (code: string) => {
    try {
      const res = await getQaOrderBySubOrderNumber(code)
      const code1 = code?.split('_')[0]
      res.data = res.data.map((item) => {
        return {
          ...item,
          isCheck: item.inspectionStatus,
        }
      })
      // 删除旧的inspectionStatus
      res.data = res.data.map(({ inspectionStatus, ...rest }) => {
        console.log(inspectionStatus)
        return rest
      })
      res.data.sort((a, b) =>
        a.isCheck === b.isCheck ? 0 : a.isCheck ? 1 : -1,
      ) //false在前，true在后
      activeTab.value = 'all'
      sourceData.value = res.data
      _sourceData.value = res.data
      allTotal.value = _sourceData.value.length
      dzjTotal.value = res.data.filter(
        (e) =>
          Number(e.shipmentNum || 0) !==
          Number(e.passNum || 0) + Number(e.notPassNum || 0),
      ).length
      yzjTotal.value = res.data.filter(
        (e) =>
          Number(e.shipmentNum || 0) ===
          Number(e.passNum || 0) + Number(e.notPassNum || 0),
      ).length
      const row = sourceData.value.find(
        (item) =>
          item.factorySubOrderNumber == code1 || item.subOrderNumber == code1,
      )
      if (row) {
        // row.passNum += 1
        currentRow.value = row
        cloneRow.value = JSON.parse(JSON.stringify(currentRow.value))
      }
      qaInputRef.value.focus()
      isLock.value = false
      qaCode.value = ''
      playAudio('picking_search_success')
    } catch (e) {
      qaInputRef.value.focus()
      isLock.value = false
      qaCode.value = ''
      // showError(e)
      playAudio('picking_search_error')
    }
  }
  // 质检完成
  const saveQuarantine = async (callback?: () => void) => {
    try {
      const data: InspectionData[] = _sourceData.value
        .filter((e) => e.isCheck)
        .map((item) => ({
          notPassCount: item.notPassNum || 0,
          subOrderNumber: item.subOrderNumber || '',
          namespace: item.namespace || '',
          erpSubOrderNumber: item.erpSubOrderNumber || '',
          billNumber: item.billNumber || '',
          version: item.version || '',
          passCount: item.passNum || 0,
          remark: item.remark || '',
        }))
      await qaFinishedApi(data)
      sourceData.value = []
      isLock.value = false
      qaInputRef.value.focus()
      qaCode.value = ''
      currentRow.value = {}
      cloneRow.value = JSON.parse(JSON.stringify(currentRow.value))
      allTotal.value = 0
      yzjTotal.value = 0
      dzjTotal.value = 0
      callback && callback()
    } catch (e) {
      // showError(e)
    }
  }
  const onQaDialogOpened = () => {
    qaInputRef.value.focus()
  }
  const onChangeTab = (key: string) => {
    activeTab.value = key
    if (key == 'all') {
      sourceData.value = _sourceData.value
    } else if (key === 'dzj') {
      sourceData.value = _sourceData.value.filter((item) => !item.isCheck)
    } else if (key === 'yzj') {
      sourceData.value = _sourceData.value.filter((item) => item.isCheck)
    }
    const row = sourceData.value.find(
      (item) => item.subOrderNumber == cloneRow.value.subOrderNumber,
    )

    if (row) {
      currentRow.value = row
    } else {
      currentRow.value = {}
    }
  }
  const onRowClick = (row: QaData) => {
    currentRow.value = row
    cloneRow.value = JSON.parse(JSON.stringify(row))
  }
  const onSuccessQc = async () => {
    if (
      (currentRow.value.passNum || 0) + (currentRow.value.notPassNum || 0) >=
      (currentRow.value.shipmentNum || 0)
    ) {
      return ElMessage({
        message: '已质检',
        type: 'warning',
        offset: window.innerHeight / 2,
      })
    }
    try {
      await showConfirm(`该产品${currentRow.value.shipmentNum}件`, {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
    } catch {
      return
    }
    currentRow.value.passNum = currentRow.value.shipmentNum
    _sourceData.value.forEach((item) => {
      if (item.subOrderNumber === currentRow.value.subOrderNumber) {
        item.isCheck = true
      }
    })
    sourceData.value = _sourceData.value

    allTotal.value = _sourceData.value.length
    dzjTotal.value = _sourceData.value.filter((item) => !item.isCheck).length
    yzjTotal.value = allTotal.value - dzjTotal.value
    qaInputRef.value.focus()
    onChangeTab(activeTab.value)
  }
  // 新的onReissue
  const giveDelivery = (form: shopRemark) => {
    const resendNum = form.resendNum ?? 0
    if (Number(resendNum) > (currentRow.value.shipmentNum || 0)) {
      return ElMessage({
        message: '重发数量不能大于发货数量',
        type: 'warning',
        offset: window.innerHeight / 2,
      })
    }
    if (resendNum > 0) {
      currentRow.value.notPassNum = Number(form.resendNum)
      currentRow.value.passNum =
        (currentRow.value.shipmentNum || 0) - Number(form.resendNum)
      currentRow.value['remark'] = form.remark ?? null
      _sourceData.value.forEach((item) => {
        if (item.subOrderNumber === currentRow.value.subOrderNumber) {
          item.isCheck = true
        }
      })

      sourceData.value = _sourceData.value

      allTotal.value = _sourceData.value.length
      dzjTotal.value = _sourceData.value.filter((item) => !item.isCheck).length
      yzjTotal.value = allTotal.value - dzjTotal.value
    } else {
      return ElMessage({
        message: '重发数量必须大于0!',
        type: 'warning',
        offset: window.innerHeight / 2,
      })
    }
  }
  const onReissue = () => {
    ElMessageBox.prompt('请输入重量', '提示', {
      confirmButtonText: '确定',
      cancelButtonText: '取消',
      inputPattern: /\d+/,
      inputErrorMessage: '请输入数字',
    }).then(({ value }) => {
      if (Number(value) > (currentRow.value.shipmentNum || 0)) {
        return ElMessage({
          message: '重发数量不能大于发货数量',
          type: 'warning',
          offset: window.innerHeight / 2,
        })
      }
      currentRow.value.notPassNum = Number(value)
      currentRow.value.passNum =
        (currentRow.value.shipmentNum || 0) - Number(value)

      _sourceData.value.forEach((item) => {
        if (item.subOrderNumber === currentRow.value.subOrderNumber) {
          item.isCheck = true
        }
      })

      sourceData.value = _sourceData.value

      allTotal.value = _sourceData.value.length
      dzjTotal.value = _sourceData.value.filter((item) => !item.isCheck).length
      yzjTotal.value = allTotal.value - dzjTotal.value
    })
  }
  /**
   * 拣货
   * picking_warning 输入错误
   * picking_beyond SKU数量超出
   * picking_check_success 验证成功
   * picking_search_error 查询失败
   * picking_search_success 查询成功
   */
  const playAudio = (key: string) => {
    const audio = new Audio()
    const audioPath = new URL(
      `../../../assets/audio/${key}.mp3`,
      import.meta.url,
    ).href
    audio.src = audioPath
    audio.play()
  }
  return {
    quarantineVisible,
    qaCode,
    qaInputRef,
    allTotal,
    dzjTotal,
    yzjTotal,
    currentRow,
    sourceData,
    activeTab,
    confirmCheck,
    searchQaByOrderNumber,
    saveQuarantine,
    onQaDialogOpened,
    onChangeTab,
    onSuccessQc,
    onReissue,
    onRowClick,
    giveDelivery,
  }
}
